;; Version 3.4
;; To facilitate the transparency of our research process and our model, we have left this code a bit "messy". As such, not all parts of the code below were used in the published paper.

extensions [ gis profiler ]
globals [
  vegetation                 ; input data of vegetation types for each patch
  cx cy                      ; xy coordinates of camp location, so agents can find their camp
  time_vt                    ; time spent in veg type (cumulative for all agents each day)
  tide                       ; keeps track of the tide; can be "poor" (most often), "OK" (8 days/month), or "good" (2 days/month)
  cum_kcal                   ; total kcal accumulated throughout simulation
  cum_km
  days-until-tide            ; days until next good tidal cycle
  springdays                 ; current count of spring tide days left, 5 on first day, decreases over course of tide
  tideday                    ; ranges from 0-14 over the tidal cycle, last 5 are springdays
  kcal_vt1
  kcal_vt2                   ; globals to keep track of kcal foraged in each vt
  kcal_vt3
  kcal_vt4
  kcal_vt5
  kcal_vt6
  kcal_vt8
  kcal_vt9
  kcal_vt10
  kcal_vt11
  kcal_vt12
  kcal_vt13
  kcal_vt14
  patches-vt
  patches-coast
  mean_dailykcal
  mean_dailykm
  time-walk-cell
  camp-mobility
  ]
patches-own [
  vt                        ; vegetation/coastal resource type
  kcal_return               ; original kcal/hr return rate for each patch  (includes coastal cell spring tide returns)
  kcal_return_min           ; same for terrestrial, but holds lower value for non-spring and non-low tides of coastal patches
  current_kcal_return       ; current kcal/hr return rate for each patch, under systematic-search-of-habitat assumption, is either vt-specific full or zero
  avg_return                ; averaged return over radius
  total-harvest-time        ; search/harvest time (hr/ha)           Varies from 0.63-17.9 hr/hectare. 17.9 is 3 or 4 person days worth of harvesting...
  pass-harvest-time         ; search/harvest time (hr/ha) to cross a patch once. Always total-time-harvest/5 since foragers cover a 20m wide swath of the 1ha cell
  goodcoast?                ; boolean to exclude Sandy Beach from coastal foraging patches   ;should replace with a goodcoast patch-set
  time-until-replenished    ; veg replenishes after 365 days, counter gets reset to zero after each instance of harvesting (no half-patches replenishing at separtate times)
  times-harvested           ; alternative way to keep track of kcal extracted by vt, doesn't work for coastal cells....
  temporal_multiplier       ; strange piece of code to weigh the returns over the next days_of_foresight
  ]
breed [agents agent]
breed [camps camp]
agents-own [
  time-forage-budget        ; time an agent has left to forage
  time-foraged              ; time agent has foraged
  dailykcal                 ; total kcal foraged each day (updated throughout the day, cleared at end of day)
  done                      ; done for the day
  timecamp                  ; travel time between forager and camp
  dailykm
  campsite                  ; camp of the agent
  days_without
]
camps-own [
  directions                ; list of directions of initial movements at the start of the day
  directioncamp             ; direction to which camp will move
  leftorright               ; randomly defined boolean whether agents go initially left or right to the camp at the start of the day
  kcal_per_day              ; total kcal accumulated each day
  kcal_total                ; total kcal accumulated throughout entire scenario
  overall_avg_kcal          ; mean kcal per agent per day
  timecoast                 ; camps track their distance to the coast, for use in mod-cog scenario
  coastal_target            ; the closest coastal patch to camp at any given time
  days_without              ; counter of days the camp brings in no calories
  ]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  ca
  reset-ticks

  ;;*****SET UP VEGETATION*****
  ifelse map-zone = "z1" OR map-zone = "z2" [
      set vegetation gis:load-dataset (word "raster_files/allhab_1ha_" map-zone ".asc")
      resize-world 0 299 0 199 set-patch-size 1.75
  ]
  [ ; full size
      set vegetation gis:load-dataset "raster_files/all_habitats_1ha.asc"
      resize-world 0 779 0 539 set-patch-size 0.45
  ]

  gis:set-world-envelope gis:envelope-of vegetation
  ;;  apply GIS data to vet types
  gis:apply-raster vegetation vt
  set patches-vt (patch-set patches with [vt > 0])
  set patches-coast (patch-set patches with [vt >= 10])

  ;; assign veg types initial kcal/hr return rates and harvest times
  ask patches-vt [
    if vt = 1  [set total-harvest-time 17.9   set kcal_return 2000]      ; Freshwater wetlands
    if vt = 2  [set total-harvest-time 13.4   set kcal_return 1160]      ; Alluvial Vegetation
    if vt = 3  [set total-harvest-time 1.17   set kcal_return 1200] ;1680]      ; Strandveld
    if vt = 4  [set total-harvest-time 0.83   set kcal_return 0]      ; Saline Vegetation
    if vt = 5  [set total-harvest-time 0.67   set kcal_return 100]      ; Renosterveld
    if vt = 6  [set total-harvest-time 0.72   set kcal_return 1022]      ; Sand Fynbos
    ;vt = 7 for wide scale?
    if vt = 8  [set total-harvest-time 0.65   set kcal_return 100]      ; Thicket
    if vt = 9  [set total-harvest-time 0.70   set kcal_return 468]     ; Limestone Fynbos
    if vt = 10 [set total-harvest-time 1.5   set kcal_return 1450   set kcal_return_min 250]      ; Aeolianite (Coastal); the coastal rates here are "poor", the most common state
    if vt = 11 [set total-harvest-time 1.5   set kcal_return 150]      ; Sandy Beach (Coastal); only coastal vt with a fixed return
    if vt = 12 [set total-harvest-time 1.5   set kcal_return 1100   set kcal_return_min 250]      ; TMS Boulders (Coastal)
    if vt = 13 [set total-harvest-time 1.5   set kcal_return 1100   set kcal_return_min 250]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set total-harvest-time 1.5   set kcal_return 1100   set kcal_return_min 250]      ; TMS Wave Cut Platforms (Coastal)

    ;test version with bumped coastal harvest rates
    ;if vt >= 10 [set kcal_return 2500]

    ifelse vt < 10 [set pass-harvest-time total-harvest-time / 5][set pass-harvest-time total-harvest-time / 3] ;5 passes needed for terrestrial, 3 passes needed for coastal (3 people deplete in 30 minutes)
    if kcal_return_min = 0 [set kcal_return_min kcal_return]         ; clone the reg return value for terrestrial patches for pick-patch-
  ]
  ;; set up goodcoast?
  ask patches [
    set goodcoast? false
    if (vt = 10 OR vt > 11)                                ; sand (11) is bad coast!
      [set goodcoast? true]
  ]

  ;;*****SET UP CAMPS*****
  create-camps nrcamps
  [
    move-to one-of patches-vt
    set cx pxcor                              ; set cx and cy for agents to find their camp
    set cy pycor
    set shape "house"
    set color red
    set size 5
    set hidden? false
  ]

  ;;*****SET UP AGENTS*****
  ;create-agents nragents
  create-agents nragents * nrcamps        ;replaced with nragents per camp, ensure this doesn't have wider implication
  [ ;set color red
    set shape "person"
    set size 5
    set time-forage-budget daily-time-budget
    set dailykcal 0
    set dailykm 0
    set hidden? false
    set campsite min-one-of camps [count agents-here ] move-to campsite
  ]

  ;;*****SET UP OTHER INITIALIZATION PARAMETERS*****
  set cum_kcal 0
  set time-walk-cell 1 / walk-speed / 10
  set camp-mobility daily-time-budget * walk-speed * 10 * 0.75        ;need to set a good value so that agents have time to harvest during the day. this was the purpose of the campless experiments but i'm not sure we came to a good answer.
  ask patches-vt [set current_kcal_return kcal_return_min]
  ask camps [ set overall_avg_kcal 0
    set kcal_total 0
    set kcal_per_day 0
  set coastal_target 0
  ]
  ask patches-vt
  [
    let temp (list)
    let i 0
    let r discount_rate
    ;repeat days_of_foresight [set temp lput (1 / i * current_kcal_return) temp set i i + 1]        ; inverse temporal distance weighting [1/1, 1/2, 1/3... 1/days_of_foresight]
    ;repeat days_of_foresight [set temp lput (1 / ((1 + r) ^ i) * current_kcal_return) temp set i i + 1]        ; weaker net present value rate 1/(1+r)^t, exponential
    repeat days_of_foresight [set temp lput (current_kcal_return / (1 + r * i)) temp set i i + 1]        ; weaker net present value rate 1/(1+r*t), hyperbolic
    set temporal_multiplier sum temp                                          ;this value is the temporally weighted return in calories for one hour a day of x days_of_foresight. Essentially a kcal/hr with foresighted days weighed in. Multiply it against daily-time-budget for total kcal harvest over those days.
  ]

  set kcal_vt1 0
  set kcal_vt2 0
  set kcal_vt3 0
  set kcal_vt4 0
  set kcal_vt5 0
  set kcal_vt6 0
  set kcal_vt8 0
  set kcal_vt9 0
  set kcal_vt10 0
  set kcal_vt11 0
  set kcal_vt12 0
  set kcal_vt13 0
  set kcal_vt14 0

  ;; display map
  ask patches with [vt = 0] [set pcolor blue]
  run (word "display-" display-mode)
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  tick
  tidal-cycle
  update-patches
  run (word "display-" display-mode)
  update-campsites
  ;ifelse (count patches with [current_kcal_return > 0] != 0) [forage][stop]
  forage
  ask camps [
    set kcal_total kcal_total + kcal_per_day
    set overall_avg_kcal (kcal_total / ticks / count agents with [campsite = myself])
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-patches
ask patches-vt
[
  ifelse vt < 10 and time-until-replenished > 0 [set time-until-replenished time-until-replenished - 1][set time-until-replenished days-until-tide]
  if time-until-replenished = 0
  [
    set current_kcal_return kcal_return
    set total-harvest-time pass-harvest-time * 5
  ]
]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to tidal-cycle
  ;; days 1-10 = poor, 11-15 = good, repeat.
  ;0: poor
  ;1: poor
  ;2: poor
  ;3: poor
  ;4: poor
  ;5: poor
  ;6: poor
  ;7: poor
  ;8: poor
  ;9: poor
  ;10: OK
  ;11: OK
  ;12: good       ; enough variation in time of year, weather, swell, that this evens out and doesn't make a difference
  ;13: OK
  ;14: OK
  set tideday remainder ticks 15

  ;; kcal returns for each tidal state
  if tideday = 0 [
    set springdays 0
    ask patches-coast [
      if current_kcal_return > kcal_return_min [set current_kcal_return kcal_return_min]
    ]
  ]
  if tideday = 10 [
    set springdays 5 + 1      ;should be 5 but substracted below so init 5 + 1
    ask patches-coast [
      set current_kcal_return kcal_return
    ]]
  set days-until-tide 10 - tideday ; there are 11 poor days in between tidal cycles
  ;print (word "days of tide left: " springdays )
  if springdays > 0 [set springdays springdays - 1]     ; possibly use as a multiplier against current_kcal_return for tidal prediction

  ; revised to take current depletion into account, took ifelse-value out of pick-patch- for patches-coast
  ask patches-coast
  [
    ;init with undepleted case
    let mult (list kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return) ; looped over two cycles to account for long temporal foresight range
    if current_kcal_return = 0
      [
        ifelse tideday < 10 [ ; case of tide being replenished at next spring
          set mult (list 0 0 0 0 0 0 0 0 0 0 kcal_return kcal_return kcal_return kcal_return kcal_return kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return)
        ]
        [ ;else tideday >= 10 ; case of tide being replenished to low at next non-spring
          set mult (list 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return)
        ]
      ]
    let sub_mult sublist mult tideday (tideday + days_of_foresight)
    let weights (list)
    let i 0
    let r discount_rate
    ;repeat days_of_foresight [set weights lput ( 1 / i ) weights set i i + 1]
    ;repeat days_of_foresight [set weights lput (1 / ((1 + r) ^ i)) weights set i i + 1]    ;exponential
    repeat days_of_foresight [set weights lput (1 / (1 + r * i)) weights set i i + 1]       ;hyperbolic time-discounting
    set temporal_multiplier sum (map * sub_mult weights)     ;should this multiplier reflect the 2h (or 4h) limit of coastal foraging?
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-campsites          ;maybe replace camp-mobility with walkable distance in day? done, calculated in setup from gui param of walk-speed and daily-time-budget
  ask camps [
    set kcal_per_day 0
    ifelse spatial-foresight = true [
      spatial-foresight-movement
    ]
    [; else spatial-foresight false = random camp mobility
      let found 0
      while [found = 0] [
        let p patch-at-heading-and-distance random 360 camp-mobility
        if p != nobody AND [vt] of p > 0
        [move-to p]
      ]; close while
    ]; close spatial-foresight else
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to spatial-foresight-movement          ;called by camps in update-campsites
  let best_pot_camp patch 0 0
  ifelse global-knowledge? [
    set best_pot_camp pick-patch-global      ;global needs to be updated
  ][
    set best_pot_camp pick-patch-local-tidal-foresight-fc
  ]
  ifelse [current_kcal_return] of best_pot_camp = 0 OR count other camps-on best_pot_camp > 0
    [
      move-to max-one-of patches-at-radius (walk-speed * 10) [current_kcal_return] ;move to a cell one hour walk away
    ]
    [ ;else target good so move to/towards
      ifelse distance best_pot_camp <= camp-mobility       ;within movement range?
      [
        move-to best_pot_camp
      ]
      [ ;else move towards location
        face best_pot_camp
        ifelse [vt] of patch-ahead camp-mobility > 0
        [
          move-to patch-ahead camp-mobility
        ]
        [ ;else there's ocean in the way
          ;move-to one-of neighbors with [vt > 0]            ; these movements too small
          move-to max-one-of patches-at-radius camp-mobility [current_kcal_return]          ; maybe an odd fix, but it works and is uncommon anyway. places camps along an camp-mobility distant arc
        ]
      ]
    ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to forage
  ;;*****INITIALIZE A NEW DAY*****
  ask agents [
    set dailykcal 0
    set dailykm 0
    set time-forage-budget daily-time-budget
    set done 0
   ]

  ;; *****ACTUAL FORAGING (INCLUDING KEEPING TRACK OF TIME AND DISTANCE TO CAMP)*****
  let allagentsdone 0
  while [allagentsdone = 0] ;all agent movement happens within a tick, good but hard to eval since you can't see inside the loop very well
    [
      ask agents with [done = 0][
        set timecamp distance campsite * time-walk-cell                             ; expected time (in minutes) for an agent to walk straight back to the camp without harvesting
        ifelse time-forage-budget > timecamp                                       ; true if time budget is less than the time it takes to cross a cell (aka time to go home)
          [ ; time left for foraging
            ; so agent moves to forage
            move
          ]
          [ ;else no time left, "forage on the way home"
            face campsite
            let found 0
            ifelse [vt] of patch-ahead 1 > 0
            [
              move-to patch-ahead 1 set found 1
            ]
            [
              while [found = 0]
              [
                if patch-ahead 1 != nobody [
                  if [vt] of patch-ahead 1 > 0 [move-to patch-ahead 1 set found 1]
                ]
                if found = 0 [rt random 45 lt random 45]
              ]
            ] ;close else patch-ahead
            set time-forage-budget time-forage-budget - time-walk-cell
            set dailykm dailykm + .1
          ] ; close else time left
        set timecamp distance campsite * time-walk-cell
        if (distance campsite < 1.5 AND time-forage-budget < time-walk-cell) OR dailykcal > max_kcal_to_harvest OR time-forage-budget < 0 [      ;next to or at campsite and foraging time has run out OR have enough kcal
          let d distance campsite
          move-to campsite ;teleports agents home if they've harvested enough
          set dailykm dailykm + d
          set done 1
        ]

      ] ;close ask agents

      if sum [done] of agents = count agents [
        set allagentsdone 1
        ask agents with [dailykcal < 100]
        [
          set days_without days_without + 1
        ]
        ask camps [
          set kcal_per_day sum [dailykcal] of agents with [campsite = myself]
          if kcal_per_day / count agents with [campsite = myself] < 100 [set days_without days_without + 1]
        ]
      ]
    ]  ;close while
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to move        ;forager procedure
  ifelse forager-movement = "random" [
    let p one-of neighbors with [current_kcal_return > 0]
    ifelse p != nobody [move-to p][move-to one-of neighbors with [vt > 0]]
  ]
  [; else if forager-movement = "local-patch-choice" [                 ; find best patch within vision radius, then move to that patch
    let best-patch pick-patch-local-tidal
    ifelse best-patch != patch-here and [current_kcal_return] of best-patch > 0
    [
      ifelse distance best-patch < 1.5                       ;if neighbouring cell move there then harvest, else move towards but don't harvest on the way
      [
        move-to best-patch
        update-numbers
      ][ ;else farther so walk towards
        face best-patch
        ifelse is-patch? patch-ahead 1 and [vt > 0] of patch-ahead 1 [
          move-to patch-ahead 1
          set time-forage-budget time-forage-budget - time-walk-cell
          set dailykm dailykm + .1
        ][ ;else     if you can't move to or towards the best, move anywhere!
          move-to one-of neighbors with [vt > 0]
          update-numbers
        ]
      ] ;close if distance
    ]
    [
      ;else best-patch is here or best-patch is empty (in dead zone)
      ifelse current_kcal_return = 0 [                                                     ; was random walking if unable to find a quality patch, now they walk towards nearest non-zero patch
        ;move-to one-of neighbors with [vt > 0]
        let p min-one-of patches with [current_kcal_return > 0] [distance myself]          ; when all cells have zero current this hits nobody and errors the next line
        ifelse p != nobody
        [
          face p ;could put in a if p != nobody switch to stop errors here
          ask p [set pcolor red]
          let dp distance p
          if [vt] of p > 0 [
            move-to p
            set time-forage-budget time-forage-budget - (time-walk-cell * dp)
            set dailykm dailykm + (.1 * dp)
          ]
        ][ ;else p is nobody, map empty
          let dp distance campsite
          move-to campsite
          set time-forage-budget 0
          set dailykm dailykm + (.1 * dp)
        ]
      ] ;maybe have them walk towards nearest non-zero return
      [ ;else
        update-numbers
      ]
    ]
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;; Mobility decision algorithms ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report pick-patch-global                  ;global knowledge not up to date currently, need to fix.
  ;report min-one-of patches-vt with-max [current_kcal_return][distance myself]
  report max-one-of patches-vt with [count camps-here = 0][current_kcal_return * (daily-time-budget - (time-walk-cell * distance myself))]                   ;this doesn't work because camp-mobility is restricted, also camps set out for tide even if not going to make it before end of spring tide
end

to-report pick-patch-local                   ;basic version of local knowledge, ie. constrained to a given radius
  ;report min-one-of patches in-radius vision with-max [current_kcal_return][distance myself]
  ifelse is-camp? self ;camps?   ;allows same function to be used by camps and foragers
  [
    report max-one-of patches in-radius vision-camp [current_kcal_return * (daily-time-budget - (time-walk-cell * distance myself))]
  ]
  [
    report max-one-of patches in-radius vision-forager [(current_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself)))]
  ]
end

to-report pick-patch-local-tidal              ;local knowledge version which includes tidal cycles
  ;report min-one-of patches in-radius vision with-max [current_kcal_return][distance myself]
  ;report max-one-of patches in-radius vision [(current_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself)))]
  ;let p max-one-of (patch-set patches in-radius vision patches-coast) [current_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself))]
  ; if coast only 2h (but 3h more terrestrial if available), if terrestrial 6h
  ifelse is-camp? self    ;supposed to be used for foragers
  [
    print "Don't use for camps"
    report one-of patches
  ]
  [
    ifelse time-forage-budget > daily-time-budget - 2 ;and days-until-tide = 0         ;low tide coastal or terrestrial, after that terrestrial only. problem since 2 tides a day, could have used torches for new moon, even without on full. Change to 4 hours and ignore that they're not sequential?
    [
      let p max-one-of (patch-set patches in-radius vision-forager patches-coast) [current_kcal_return * (2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself))]
      ;ask p [set pcolor red]
      report p
    ]
    [ ;else rest of day on terrestrial
      let p max-one-of patches in-radius vision-forager [ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min][current_kcal_return] * ([time-forage-budget] of myself - (time-walk-cell * distance myself))]
      ;ask p [set pcolor red]
      report p
    ]
  ]
end

to-report pick-patch-local-tidal-land     ;forager decision including tidal cycle and adjacent terrestrial cell for high-tide hours
  let p max-one-of (patch-set patches in-radius vision-forager with [vt > 0] patches-coast)
    [
      max (list
        ;marine: if (daily-left) + travel < tide, tide - (daily-left) - travel, 0
        ((current_kcal_return * (ifelse-value ((daily-time-budget - [time-forage-budget] of myself) + (time-walk-cell * distance myself) < 2) [2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself)][0])) +
        ;terrestrial: if (daily-left) + travel < tide, daily-tide, left-travel
          ([current_kcal_return] of one-of patches in-radius 1.5 with [vt > 0 AND vt < 10] * ;flags if local cells empty, switch to mini max-one-of?
            ifelse-value ((daily-time-budget - [time-forage-budget] of myself) + (time-walk-cell * distance myself) < 2) [daily-time-budget - 2] [[time-forage-budget] of myself - (time-walk-cell * distance myself)]
            ))
        (ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min] [current_kcal_return] * ([time-forage-budget] of myself - (time-walk-cell * distance myself)))
      )
    ]
  report p
end


to-report pick-patch-local-tidal-foresight               ;camp procedure with local knowledge version which includes tidal cycles and temporal foresight
  ifelse is-camp? self
  [
    let p max-one-of (patch-set patches in-radius vision-camp patches-coast) [
      ifelse-value goodcoast?
      [
        (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * 2) + ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
      ]
      [
        ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
      ]
    ]

    ask p [set pcolor cyan]
    report p

  ]
  [
    print "Don't use for foragers"
    report one-of patches
  ]
end

to-report pick-patch-local-tidal-foresight-avg         ;adding avg over radius. Works but is very slow.

  ifelse is-camp? self
  [
    let p max-one-of (patch-set patches in-radius vision-camp patches-coast) [
      ifelse-value goodcoast?
      [
        (ifelse-value (avg_return > 0) [temporal_multiplier] [0] * 2) + ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) - (distance myself / camp-mobility * daily-time-budget * avg_return)

      ]
      [
        ifelse-value (avg_return > 0) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * avg_return)
      ]
    ]

    ask p [set pcolor cyan]
    report p

  ]
  [
    print "Don't use for foragers"
    report one-of patches
  ]
end

to-report pick-patch-local-tidal-foresight-fc         ;with fixed movement cost, add comparison to non-moving staying put (and remove local cell set zero)
  ifelse is-camp? self
  [
    let p max-one-of (patch-set patches in-radius vision-camp patches-coast) [
      ifelse-value goodcoast?
      [
        (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * 2) + ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) - (((distance myself / camp-mobility * daily-time-budget) - 1) * current_kcal_return)
      ]
      [
        ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * daily-time-budget - (((distance myself / camp-mobility * daily-time-budget) - 1) * current_kcal_return)
      ]
    ]

    ask p [set pcolor cyan]
    report p

  ]
  [
    print "Don't use for foragers"
    report one-of patches
  ]
end

to-report pick-patch-local-tidal-foresight_image            ;cleaned version to make a screenshot of code for CAA2016 slides
  let p max-one-of (patch-set patches in-radius vision-camp patches-coast) [
    ifelse-value goodcoast?
    [
      (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * 2) +
      ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) -
      (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
    ]
    [
      ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
    ]
  ]
  ask p [set pcolor cyan]
  report p
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report kcal-avg
    report mean [overall_avg_kcal] of camps
end

to display-vt
  ask patches-vt [
    ;if vt = 0  [set pcolor 105]     ; no data; blue to simulate water
    if vt = 1  [set pcolor 88]      ; Freshwater wetlands
    if vt = 2  [set pcolor 86]      ; Alluvial Vegetation
    if vt = 3  [set pcolor 116]     ; Strandveld
    if vt = 4  [set pcolor 16]      ; Saline Vegetation
    if vt = 5  [set pcolor 46]      ; Renosterveld
    if vt = 6  [set pcolor 56]      ; Sand Fynbos
    if vt = 8  [set pcolor 76]      ; Thicket
    if vt = 9  [set pcolor 126]     ; Limestone Fynbos
    if vt = 10 [set pcolor 53]      ; Aeolianite (Coastal)
    if vt = 11 [set pcolor 26]      ; Sandy Beach (Coastal)
    if vt = 12 [set pcolor 34]      ; TMS Boulders (Coastal)
    if vt = 13 [set pcolor 35]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set pcolor 36]      ; TMS Wave Cut Platforms (Coastal)
  ]
end

to display-kcal             ;this is logged ; could be turned to single patch, then ask patches in go code... avoid dupe in update-patches
  let max-cal 1500 ;max [kcal_return] of patches
  ;ifelse ticks > 0 [ask patches-vt [set pcolor scale-color green log (current_kcal_return + 1) 10 0 log max-cal 10]][ask patches-vt [set pcolor scale-color green log (current_kcal_return + 1) 10 0 log max-cal 10]]
  ;ifelse ticks > 0 [ask patches-vt [set pcolor scale-color green current_kcal_return 0 max-cal]][ask patches-vt [set pcolor scale-color green current_kcal_return 0 max-cal ]]
  ask patches-vt [
    ifelse current_kcal_return > 0 [set pcolor scale-color green current_kcal_return 0 max-cal][set pcolor 2]
  ]
end

to display-hybrid     ; returns shades of each colour based on current kcal return rate, darker shades represent a harvested patch. Looks good but is too slow to be generally useful.
    ask patches-vt [
    ;if vt = 0  [set pcolor 105]     ; no data; blue to simulate water
    if vt = 1  [set pcolor 88 - (1 - current_kcal_return / kcal_return)]      ; Freshwater wetlands
    if vt = 2  [set pcolor 86 - (1 - current_kcal_return / kcal_return)]      ; Alluvial Vegetation
    if vt = 3  [set pcolor 116 - (1 - current_kcal_return / kcal_return)]     ; Strandveld
    if vt = 4  [set pcolor 16 - (1 - current_kcal_return / kcal_return)]      ; Saline Vegetation
    if vt = 5  [set pcolor 46 - (1 - current_kcal_return / kcal_return)]      ; Renosterveld
    if vt = 6  [set pcolor 56 - (1 - current_kcal_return / kcal_return)]      ; Sand Fynbos
    if vt = 8  [set pcolor 76 - (1 - current_kcal_return / kcal_return)]      ; Thicket
    if vt = 9  [set pcolor 126 - (1 - current_kcal_return / kcal_return)]     ; Limestone Fynbos
    if vt = 10 [set pcolor 53 - (1 - current_kcal_return / kcal_return)]      ; Aeolianite (Coastal)
    if vt = 11 [set pcolor 26 - (1 - current_kcal_return / kcal_return)]      ; Sandy Beach (Coastal)
    if vt = 12 [set pcolor 34 - (1 - current_kcal_return / kcal_return)]      ; TMS Boulders (Coastal)
    if vt = 13 [set pcolor 35 - (1 - current_kcal_return / kcal_return)]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set pcolor 36 - (1 - current_kcal_return / kcal_return)]      ; TMS Wave Cut Platforms (Coastal)
  ]
end

to-report patches-at-radius [rad]
    ;ask camps [ask patches-at-radius rad [blah]]
    report (patch-set patches-vt with [distance myself > rad - 1 AND distance myself <= rad])
end

to display-none
  if ticks <= 1 [display-vt]
end

to display-time-replenished
  ask patches-vt
  [
    if ticks > 0 [set pcolor scale-color red time-until-replenished 365 0]
  ]
end

to display-times-harvested
  let max-harvest max [times-harvested] of patches
  ask patches-vt
  [
    if ticks > 0 [set pcolor scale-color red times-harvested 0 (max-harvest + 1)]
  ]
end

to update-numbers          ; this is the accounting of harvesting agents and depleting patches
  set dailykcal dailykcal + (pass-harvest-time * current_kcal_return)
  set dailykm dailykm + .1
  ifelse total-harvest-time > 0
  [
    set time-forage-budget time-forage-budget - pass-harvest-time
    ask patch-here [
      set total-harvest-time total-harvest-time - pass-harvest-time
      set times-harvested times-harvested + 1
      if total-harvest-time <= 0 [set total-harvest-time 0 set current_kcal_return 0 set time-until-replenished 365 set pcolor black]

    ]
  ][ ;else already all harvested
    set time-forage-budget time-forage-budget - time-walk-cell
  ]

end

to test1
   ask pick-patch-global [set pcolor red]
end

to test2
  ask pick-patch-local [set pcolor yellow]
end

to test3
  ask pick-patch-local-tidal-land [set pcolor orange]
end

to test4
  ask pick-patch-local-tidal-foresight [
    set pcolor cyan
    ;ifelse-value (current_kcal_return > 0 or goodcoast?) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return * temporal_multiplier_general)
    ;print (word "kcal term: " (ifelse-value (current_kcal_return > 0 or goodcoast?) [temporal_multiplier] [0] * daily-time-budget) " distance term: " (distance myself / camp-mobility * daily-time-budget * current_kcal_return ) " result: " (ifelse-value (current_kcal_return > 0 or goodcoast?) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return )))
    ]
end

to test5
  ask patches-vt [set avg_return mean [current_kcal_return] of patches in-radius 5 with [current_kcal_return > 0]]
  ask pick-patch-local-tidal-foresight-avg [
    set pcolor yellow
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
226
10
761
391
-1
-1
1.75
1
8
1
1
1
0
0
0
1
0
299
0
199
0
0
1
ticks
30.0

BUTTON
3
10
126
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
3
43
126
76
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
147
127
180
nragents
nragents
1
50
7
1
1
NIL
HORIZONTAL

BUTTON
3
76
126
109
tick
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
4
427
127
472
forager-movement
forager-movement
"random" "local-patch-choice"
1

MONITOR
773
11
912
56
mean-daily-kcal-per-agent
kcal-avg
0
1
11

PLOT
764
395
1283
636
time-foraged-by-habitat
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"Alluvial" 1.0 1 -8990512 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 2] / sum [time-foraged-here] of patches]]"
"Strandveld" 1.0 1 -6917194 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 3] / sum [time-foraged-here] of patches]]"
"Saline" 1.0 1 -2139308 true "" ";if plots? [if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 4] / sum [time-foraged-here] of patches]]]"
"Renosterveld" 1.0 1 -987046 true "" ";if plots? [if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 5] / sum [time-foraged-here] of patches]]]"
"Sand Fynbos" 1.0 1 -8732573 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 6] / sum [time-foraged-here] of patches]]"
"Thicket" 1.0 1 -11881837 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 8] / sum [time-foraged-here] of patches]]"
"Limestone Fynbos" 1.0 1 -4699768 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 9] / sum [time-foraged-here] of patches]]"
"Aeolianite" 1.0 1 -13210332 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 10] / sum [time-foraged-here] of patches]]"
"Sandy Beach" 1.0 1 -817084 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 11] / sum [time-foraged-here] of patches]]"
"TMS Boulders" 1.0 1 -8431303 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 12] / sum [time-foraged-here] of patches]]"
"TMS Eroded Rocky Headlands" 1.0 1 -6459832 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 13] / sum [time-foraged-here] of patches]]"
"TMS Wave Cut Platforms" 1.0 1 -5207188 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 14] / sum [time-foraged-here] of patches]]"
"Freshwater wetlands" 1.0 0 -4528153 true "" ";if plots? [if ticks > 0 [plot sum [time-foraged-here] of patches with [vt = 1] / sum [time-foraged-here] of patches]]"

SWITCH
4
517
127
550
spatial-foresight
spatial-foresight
0
1
-1000

PLOT
921
11
1121
161
daily kcal
NIL
NIL
0.0
10.0
0.0
2000.0
true
false
"" ""
PENS
"dailykcal" 1.0 0 -7500403 true "" "if plots? [if ticks > 0 [plotxy ticks mean [dailykcal] of agents]]"
"mean_daily_kcal" 1.0 0 -14439633 true "" ";if plots? [ask camps [plotxy ticks overall_avg_kcal]]\nif plots? and ticks > 0 [plotxy ticks kcal-avg]"

SLIDER
2
241
124
274
vision-camp
vision-camp
0
50
50
5
1
NIL
HORIZONTAL

SLIDER
2
274
125
307
vision-forager
vision-forager
0
75
75
5
1
NIL
HORIZONTAL

MONITOR
818
110
868
155
NIL
days-until-tide
17
1
11

BUTTON
1135
15
1206
48
profiler
setup                  ;; set up the model\nprofiler:start         ;; start profiling\nrepeat 10 [ go ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
359
395
559
545
Mean daily km
ticks
current-kcal-return
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if plots? [plotxy ticks mean_dailykm]"
"Running mean" 1.0 0 -8330359 true "" "if plots? and ticks > 0 [plotxy ticks (cum_km / nragents / ticks)]"

PLOT
560
395
760
545
coast distance
ticks
distance from coast
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if plots? and ticks > 0 [plotxy ticks mean [distance min-one-of patches with [goodcoast? = true] [distance myself]] of camps]"

SWITCH
1131
132
1234
165
plots?
plots?
1
1
-1000

CHOOSER
144
529
268
574
map-zone
map-zone
"z1" "z2" "full"
0

BUTTON
1134
56
1247
89
profiler module
profiler:start         ;; start profiling\nrepeat 10 [ \nask camps [\n  test4\n  test5\n]\n]\n       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
144
484
284
529
display-mode
display-mode
"vt" "kcal" "hybrid" "time-replenished" "times-harvested" "none"
1

BUTTON
82
215
137
248
range
  ask one-of camps [\n    ask patches-at-radius vision-camp [set pcolor red]\n    ask patches-at-radius camp-mobility [set pcolor blue]\n  ]\nask one-of agents [\n  ask patches-at-radius vision-forager [set pcolor yellow] \n  ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
3
340
125
385
daily-time-budget
daily-time-budget
5.9 10
0

MONITOR
773
56
912
101
mean-daily-km-per-agent
mean_dailykm
0
1
11

SWITCH
4
551
126
584
global-knowledge?
global-knowledge?
1
1
-1000

BUTTON
1135
95
1248
128
profile-noreset
profiler:start         ;; start profiling\nrepeat 10 [ go ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
180
127
213
nrcamps
nrcamps
0
30
6
1
1
NIL
HORIZONTAL

SLIDER
2
307
125
340
walk-speed
walk-speed
1
10
2
1
1
km/hr
HORIZONTAL

MONITOR
3
384
125
429
camp-mobility (in cells)
camp-mobility
1
1
11

SLIDER
4
584
127
617
max_kcal_to_harvest
max_kcal_to_harvest
0
5000
5000
1000
1
NIL
HORIZONTAL

MONITOR
868
110
918
155
NIL
springdays
0
1
11

MONITOR
768
110
818
155
NIL
tideday
0
1
11

SLIDER
128
272
220
305
days_of_foresight
days_of_foresight
1
5
5
1
1
NIL
HORIZONTAL

BUTTON
768
155
840
188
bluepicks
;ask camp 0 [repeat 100 [test4 ask pick-patch-local-tidal-foresight [set current_kcal_return 0]]]\n;repeat 100 [ask camps [test4 ask pick-patch-local-tidal-foresight [set current_kcal_return 0]]]\nrepeat 10 [\n\nask camps [test5 ask pick-patch-local-tidal-foresight-avg [set current_kcal_return 0]]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
840
155
911
188
travel days
ask patches [set plabel \"\"]\nask camp 0 [ask n-of 100 patches in-radius vision-camp [set plabel-color blue set plabel precision (distance myself / camp-mobility) 1]]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
768
188
841
221
distweight
ask patches [set plabel \"\"]\nask camp 2 [ask n-of 30 (patch-set patches in-radius vision-camp patches-coast)[set plabel round (ifelse-value (current_kcal_return > 0 or goodcoast?) [temporal_multiplier] [0] * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return ))]]\nask camp 2 [test4]\n;ask camp 2 [inspect pick-patch-local-tidal-foresight]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
124
307
187
340
mob
set camp-mobility daily-time-budget * walk-speed * 10 * .75
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
138
214
219
274
discount_rate
0.1
1
0
Number

BUTTON
768
220
841
253
dw forager
ask patches [set plabel \"\"]\nask agent 10 [ask n-of 30 (patch-set patches in-radius vision-camp patches-coast)[\n  set plabel round (\n      max (list\n      (current_kcal_return * (2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself)))\n      (ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min] [current_kcal_return] * ([time-forage-budget] of myself - (time-walk-cell * distance myself))) \n      ))\n]\n]\n\nask agent 10 [ask pick-patch-local-tidal-land [\n  set plabel round (\n      max (list\n      (current_kcal_return * (2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself)))\n      (ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min] [current_kcal_return] * ([time-forage-budget] of myself - (time-walk-cell * distance myself))) \n      ))\n]\n]\nask agent 10 [test3]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## Model details
See the accompanying ODD protocol file.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="CAA_runs z2 &amp; discount_rate 0.1 only" repetitions="5" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <timeLimit steps="3650"/>
    <metric>kcal-avg</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 1]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 2]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 3]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 4]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 5]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 6]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 7]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 8]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 9]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 10]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 11]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt &gt;= 12]</metric>
    <metric>mean [days_without] of camps / ticks</metric>
    <metric>mean [days_without] of agents / ticks</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="nrcamps">
      <value value="7"/>
      <value value="5"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nragents">
      <value value="15"/>
      <value value="10"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="5.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-camp">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CAA_runs pops_30" repetitions="5" runMetricsEveryStep="false">
    <setup>reset-timer
setup</setup>
    <go>go</go>
    <timeLimit steps="3650"/>
    <metric>kcal-avg</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 1]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 2]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 3]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 4]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 5]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 6]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 7]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 8]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 9]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 10]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt = 11]</metric>
    <metric>sum [times-harvested * kcal_return] of patches with [vt &gt;= 12]</metric>
    <metric>mean [days_without] of camps / ticks</metric>
    <metric>mean [days_without] of agents / ticks</metric>
    <metric>timer</metric>
    <enumeratedValueSet variable="nrcamps">
      <value value="5"/>
      <value value="3"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nragents">
      <value value="6"/>
      <value value="5"/>
      <value value="4"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="5.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-camp">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
